autowisp.astrometry.healpix_utilities module — AutoWISP documentation

# autowisp.astrometry.healpix_utilities module

## Class Inheritance Diagram

Simple functions useful when interacing with HEALpix library.

autowisp.astrometry.healpix_utilities.square_query_vertices(center, size, rotation=0.0)

  Vertices defining a rectangular query to pass to healpy.query_polygon.

  Parameters:

    - center – The RA, Dec coordinates of the center of the query in degrees.

    - size – The full width/height of the rectangular region to query in degrees. If a single value, a square region is costructed.

    - rotation – The angle in degrees between the up direction in the query region and north. Going positive from zero corresponds to the up direction picking up a positve component along RA.

  Returns:

    The 4 unit vectors of the corners of the query on the unit sphere.

  Return type:

    array with shape (4, 3)